@@ -7,7 +7,7 @@ BEGIN {
 }
 
 
-our $VERSION =  '0.04.01';
+our $VERSION =  '0.05.01';
 
 =head1 NAME
 
@@ -1550,7 +1550,7 @@ channel.
 
 =head1 AUTHOR
 
-Eugen Konkov <kes-kes@yandex.ru>
+Eugen Konkov <cpan@konkov.top>
 
 =head1 COPYRIGHT
 
